Module state

Module state 

Application state for the TUI

This module defines the state that drives the TUI rendering.

Structs

AppState
The current state of the application
StatusMessage
A status message with timestamp

Enums

ExecutionMode
The execution mode determines which executor backend to use
StatusLevel
Status message level