Application state for the TUI
This module defines the state that drives the TUI rendering.
Structs
- AppState
- The current state of the application
- Status
Message - A status message with timestamp
Enums
- Execution
Mode - The execution mode determines which executor backend to use
- Status
Level - Status message level